@@ -18,6 +18,16 @@ pub enum Priority {
 
     /// Extra
     Extra,
+
+    /// Source
+    ///
+    /// Note: This priority is not officially documented in Debian policy,
+    /// but is commonly used to indicate source packages.
+    ///
+    /// While packages generally follow the priority values defined in policy, for source packages
+    /// the archive-management software (such as dak, the
+    /// Debian Archive Kit) may set "Priority: source".
+    Source,
 }
 
 impl std::fmt::Display for Priority {
@@ -28,6 +38,7 @@ impl std::fmt::Display for Priority {
             Priority::Standard => "standard",
             Priority::Optional => "optional",
             Priority::Extra => "extra",
+            Priority::Source => "source",
         })
     }
 }
@@ -42,6 +53,7 @@ impl std::str::FromStr for Priority {
             "standard" => Ok(Priority::Standard),
             "optional" => Ok(Priority::Optional),
             "extra" => Ok(Priority::Extra),
+            "source" => Ok(Priority::Source),
             _ => Err(format!("Invalid priority: {}", s)),
         }
     }
